pub struct DeviceStatus(/* private fields */);Expand description
Status register for DS2484 The read-only Status register is the general means for the DS2484 to report bit-type data from the 1-Wire side, 1-Wire busy status, and its own reset status to the host processor (Table 3). All 1-Wire communication commands and the Device Reset command position the read pointer at the Status register for the host processor to read with minimal protocol overhead. Status information is updated during the execution of certain commands only. Bit details are given in the following descriptions.
Implementations
Sourceimpl DeviceStatus
impl DeviceStatus
Sourcepub const fn logic_level(&self) -> bool
pub const fn logic_level(&self) -> bool
The LL bit reports the logic state of the active 1-Wire line without initiating any 1-Wire communication. The 1-Wire line is sampled for this purpose every time the Status register is read. The sampling and updating of the LL bit takes place when the host processor has addressed the DS2484 in read mode (during the acknowledge cycle), provided that the read pointer is positioned at the Status register.
Bits: 3..4
Sourcepub const fn device_reset(&self) -> bool
pub const fn device_reset(&self) -> bool
If the RST bit is 1, the DS2484 has performed an internal reset cycle, either caused by a power-on reset or from executing the Device Reset command. The RST bit is cleared automatically when the DS2484 executes a Write Device Configuration command to restore the selection of the desired 1-Wire features.
Bits: 4..5